@@ -13,11 +13,15 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import Any, Dict, List, Union
+from typing import Any, Dict, List, Sequence, Union
 
 from .literals import (
+    AugmentedManifestsDocumentTypeFormatType,
     DocumentClassifierDataFormatType,
     DocumentClassifierModeType,
+    DocumentReadActionType,
+    DocumentReadFeatureTypesType,
+    DocumentReadModeType,
     EndpointStatusType,
     EntityRecognizerDataFormatType,
     EntityTypeType,
@@ -30,6 +34,7 @@ from .literals import (
     PiiEntitiesDetectionModeType,
     PiiEntityTypeType,
     SentimentTypeType,
+    SplitType,
     SyntaxLanguageCodeType,
 )
 
@@ -113,7 +118,9 @@ __all__ = (
     "DocumentClassifierInputDataConfigTypeDef",
     "DocumentClassifierOutputDataConfigTypeDef",
     "DocumentClassifierPropertiesTypeDef",
+    "DocumentClassifierSummaryTypeDef",
     "DocumentLabelTypeDef",
+    "DocumentReaderConfigTypeDef",
     "DominantLanguageDetectionJobFilterTypeDef",
     "DominantLanguageDetectionJobPropertiesTypeDef",
     "DominantLanguageTypeDef",
@@ -131,6 +138,7 @@ __all__ = (
     "EntityRecognizerMetadataEntityTypesListItemTypeDef",
     "EntityRecognizerMetadataTypeDef",
     "EntityRecognizerPropertiesTypeDef",
+    "EntityRecognizerSummaryTypeDef",
     "EntityTypeDef",
     "EntityTypesEvaluationMetricsTypeDef",
     "EntityTypesListItemTypeDef",
@@ -142,6 +150,8 @@ __all__ = (
     "KeyPhrasesDetectionJobPropertiesTypeDef",
     "ListDocumentClassificationJobsRequestRequestTypeDef",
     "ListDocumentClassificationJobsResponseTypeDef",
+    "ListDocumentClassifierSummariesRequestRequestTypeDef",
+    "ListDocumentClassifierSummariesResponseTypeDef",
     "ListDocumentClassifiersRequestRequestTypeDef",
     "ListDocumentClassifiersResponseTypeDef",
     "ListDominantLanguageDetectionJobsRequestRequestTypeDef",
@@ -150,6 +160,8 @@ __all__ = (
     "ListEndpointsResponseTypeDef",
     "ListEntitiesDetectionJobsRequestRequestTypeDef",
     "ListEntitiesDetectionJobsResponseTypeDef",
+    "ListEntityRecognizerSummariesRequestRequestTypeDef",
+    "ListEntityRecognizerSummariesResponseTypeDef",
     "ListEntityRecognizersRequestRequestTypeDef",
     "ListEntityRecognizersResponseTypeDef",
     "ListEventsDetectionJobsRequestRequestTypeDef",
@@ -216,13 +228,30 @@ __all__ = (
     "VpcConfigTypeDef",
 )
 
-AugmentedManifestsListItemTypeDef = TypedDict(
-    "AugmentedManifestsListItemTypeDef",
+_RequiredAugmentedManifestsListItemTypeDef = TypedDict(
+    "_RequiredAugmentedManifestsListItemTypeDef",
     {
         "S3Uri": str,
-        "AttributeNames": List[str],
+        "AttributeNames": Sequence[str],
     },
 )
+_OptionalAugmentedManifestsListItemTypeDef = TypedDict(
+    "_OptionalAugmentedManifestsListItemTypeDef",
+    {
+        "Split": SplitType,
+        "AnnotationDataS3Uri": str,
+        "SourceDocumentsS3Uri": str,
+        "DocumentType": AugmentedManifestsDocumentTypeFormatType,
+    },
+    total=False,
+)
+
+
+class AugmentedManifestsListItemTypeDef(
+    _RequiredAugmentedManifestsListItemTypeDef, _OptionalAugmentedManifestsListItemTypeDef
+):
+    pass
+
 
 BatchDetectDominantLanguageItemResultTypeDef = TypedDict(
     "BatchDetectDominantLanguageItemResultTypeDef",
@@ -236,7 +265,7 @@ BatchDetectDominantLanguageItemResultTypeDef = TypedDict(
 BatchDetectDominantLanguageRequestRequestTypeDef = TypedDict(
     "BatchDetectDominantLanguageRequestRequestTypeDef",
     {
-        "TextList": List[str],
+        "TextList": Sequence[str],
     },
 )
 
@@ -261,7 +290,7 @@ BatchDetectEntitiesItemResultTypeDef = TypedDict(
 BatchDetectEntitiesRequestRequestTypeDef = TypedDict(
     "BatchDetectEntitiesRequestRequestTypeDef",
     {
-        "TextList": List[str],
+        "TextList": Sequence[str],
         "LanguageCode": LanguageCodeType,
     },
 )
@@ -287,7 +316,7 @@ BatchDetectKeyPhrasesItemResultTypeDef = TypedDict(
 BatchDetectKeyPhrasesRequestRequestTypeDef = TypedDict(
     "BatchDetectKeyPhrasesRequestRequestTypeDef",
     {
-        "TextList": List[str],
+        "TextList": Sequence[str],
         "LanguageCode": LanguageCodeType,
     },
 )
@@ -314,7 +343,7 @@ BatchDetectSentimentItemResultTypeDef = TypedDict(
 BatchDetectSentimentRequestRequestTypeDef = TypedDict(
     "BatchDetectSentimentRequestRequestTypeDef",
     {
-        "TextList": List[str],
+        "TextList": Sequence[str],
         "LanguageCode": LanguageCodeType,
     },
 )
@@ -340,7 +369,7 @@ BatchDetectSyntaxItemResultTypeDef = TypedDict(
 BatchDetectSyntaxRequestRequestTypeDef = TypedDict(
     "BatchDetectSyntaxRequestRequestTypeDef",
     {
-        "TextList": List[str],
+        "TextList": Sequence[str],
         "LanguageCode": SyntaxLanguageCodeType,
     },
 )
@@ -435,7 +464,8 @@ _RequiredCreateDocumentClassifierRequestRequestTypeDef = TypedDict(
 _OptionalCreateDocumentClassifierRequestRequestTypeDef = TypedDict(
     "_OptionalCreateDocumentClassifierRequestRequestTypeDef",
     {
-        "Tags": List["TagTypeDef"],
+        "VersionName": str,
+        "Tags": Sequence["TagTypeDef"],
         "OutputDataConfig": "DocumentClassifierOutputDataConfigTypeDef",
         "ClientRequestToken": str,
         "VolumeKmsKeyId": str,
@@ -474,7 +504,7 @@ _OptionalCreateEndpointRequestRequestTypeDef = TypedDict(
     "_OptionalCreateEndpointRequestRequestTypeDef",
     {
         "ClientRequestToken": str,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
         "DataAccessRoleArn": str,
     },
     total=False,
@@ -507,7 +537,8 @@ _RequiredCreateEntityRecognizerRequestRequestTypeDef = TypedDict(
 _OptionalCreateEntityRecognizerRequestRequestTypeDef = TypedDict(
     "_OptionalCreateEntityRecognizerRequestRequestTypeDef",
     {
-        "Tags": List["TagTypeDef"],
+        "VersionName": str,
+        "Tags": Sequence["TagTypeDef"],
         "ClientRequestToken": str,
         "VolumeKmsKeyId": str,
         "VpcConfig": "VpcConfigTypeDef",
@@ -872,6 +903,7 @@ DocumentClassifierFilterTypeDef = TypedDict(
     "DocumentClassifierFilterTypeDef",
     {
         "Status": ModelStatusType,
+        "DocumentClassifierName": str,
         "SubmitTimeBefore": Union[datetime, str],
         "SubmitTimeAfter": Union[datetime, str],
     },
@@ -883,8 +915,9 @@ DocumentClassifierInputDataConfigTypeDef = TypedDict(
     {
         "DataFormat": DocumentClassifierDataFormatType,
         "S3Uri": str,
+        "TestS3Uri": str,
         "LabelDelimiter": str,
-        "AugmentedManifests": List["AugmentedManifestsListItemTypeDef"],
+        "AugmentedManifests": Sequence["AugmentedManifestsListItemTypeDef"],
     },
     total=False,
 )
@@ -917,6 +950,19 @@ DocumentClassifierPropertiesTypeDef = TypedDict(
         "VpcConfig": "VpcConfigTypeDef",
         "Mode": DocumentClassifierModeType,
         "ModelKmsKeyId": str,
+        "VersionName": str,
+    },
+    total=False,
+)
+
+DocumentClassifierSummaryTypeDef = TypedDict(
+    "DocumentClassifierSummaryTypeDef",
+    {
+        "DocumentClassifierName": str,
+        "NumberOfVersions": int,
+        "LatestVersionCreatedAt": datetime,
+        "LatestVersionName": str,
+        "LatestVersionStatus": ModelStatusType,
     },
     total=False,
 )
@@ -930,6 +976,28 @@ DocumentLabelTypeDef = TypedDict(
     total=False,
 )
 
+_RequiredDocumentReaderConfigTypeDef = TypedDict(
+    "_RequiredDocumentReaderConfigTypeDef",
+    {
+        "DocumentReadAction": DocumentReadActionType,
+    },
+)
+_OptionalDocumentReaderConfigTypeDef = TypedDict(
+    "_OptionalDocumentReaderConfigTypeDef",
+    {
+        "DocumentReadMode": DocumentReadModeType,
+        "FeatureTypes": List[DocumentReadFeatureTypesType],
+    },
+    total=False,
+)
+
+
+class DocumentReaderConfigTypeDef(
+    _RequiredDocumentReaderConfigTypeDef, _OptionalDocumentReaderConfigTypeDef
+):
+    pass
+
+
 DominantLanguageDetectionJobFilterTypeDef = TypedDict(
     "DominantLanguageDetectionJobFilterTypeDef",
     {
@@ -987,11 +1055,13 @@ EndpointPropertiesTypeDef = TypedDict(
         "Status": EndpointStatusType,
         "Message": str,
         "ModelArn": str,
+        "DesiredModelArn": str,
         "DesiredInferenceUnits": int,
         "CurrentInferenceUnits": int,
         "CreationTime": datetime,
         "LastModifiedTime": datetime,
         "DataAccessRoleArn": str,
+        "DesiredDataAccessRoleArn": str,
     },
     total=False,
 )
@@ -1037,19 +1107,48 @@ EntityLabelTypeDef = TypedDict(
     total=False,
 )
 
-EntityRecognizerAnnotationsTypeDef = TypedDict(
-    "EntityRecognizerAnnotationsTypeDef",
+_RequiredEntityRecognizerAnnotationsTypeDef = TypedDict(
+    "_RequiredEntityRecognizerAnnotationsTypeDef",
     {
         "S3Uri": str,
     },
 )
+_OptionalEntityRecognizerAnnotationsTypeDef = TypedDict(
+    "_OptionalEntityRecognizerAnnotationsTypeDef",
+    {
+        "TestS3Uri": str,
+    },
+    total=False,
+)
 
-EntityRecognizerDocumentsTypeDef = TypedDict(
-    "EntityRecognizerDocumentsTypeDef",
+
+class EntityRecognizerAnnotationsTypeDef(
+    _RequiredEntityRecognizerAnnotationsTypeDef, _OptionalEntityRecognizerAnnotationsTypeDef
+):
+    pass
+
+
+_RequiredEntityRecognizerDocumentsTypeDef = TypedDict(
+    "_RequiredEntityRecognizerDocumentsTypeDef",
     {
         "S3Uri": str,
     },
 )
+_OptionalEntityRecognizerDocumentsTypeDef = TypedDict(
+    "_OptionalEntityRecognizerDocumentsTypeDef",
+    {
+        "TestS3Uri": str,
+        "InputFormat": InputFormatType,
+    },
+    total=False,
+)
+
+
+class EntityRecognizerDocumentsTypeDef(
+    _RequiredEntityRecognizerDocumentsTypeDef, _OptionalEntityRecognizerDocumentsTypeDef
+):
+    pass
+
 
 EntityRecognizerEntityListTypeDef = TypedDict(
     "EntityRecognizerEntityListTypeDef",
@@ -1072,6 +1171,7 @@ EntityRecognizerFilterTypeDef = TypedDict(
     "EntityRecognizerFilterTypeDef",
     {
         "Status": ModelStatusType,
+        "RecognizerName": str,
         "SubmitTimeBefore": Union[datetime, str],
         "SubmitTimeAfter": Union[datetime, str],
     },
@@ -1081,7 +1181,7 @@ EntityRecognizerFilterTypeDef = TypedDict(
 _RequiredEntityRecognizerInputDataConfigTypeDef = TypedDict(
     "_RequiredEntityRecognizerInputDataConfigTypeDef",
     {
-        "EntityTypes": List["EntityTypesListItemTypeDef"],
+        "EntityTypes": Sequence["EntityTypesListItemTypeDef"],
     },
 )
 _OptionalEntityRecognizerInputDataConfigTypeDef = TypedDict(
@@ -1091,7 +1191,7 @@ _OptionalEntityRecognizerInputDataConfigTypeDef = TypedDict(
         "Documents": "EntityRecognizerDocumentsTypeDef",
         "Annotations": "EntityRecognizerAnnotationsTypeDef",
         "EntityList": "EntityRecognizerEntityListTypeDef",
-        "AugmentedManifests": List["AugmentedManifestsListItemTypeDef"],
+        "AugmentedManifests": Sequence["AugmentedManifestsListItemTypeDef"],
     },
     total=False,
 )
@@ -1141,6 +1241,19 @@ EntityRecognizerPropertiesTypeDef = TypedDict(
         "VolumeKmsKeyId": str,
         "VpcConfig": "VpcConfigTypeDef",
         "ModelKmsKeyId": str,
+        "VersionName": str,
+    },
+    total=False,
+)
+
+EntityRecognizerSummaryTypeDef = TypedDict(
+    "EntityRecognizerSummaryTypeDef",
+    {
+        "RecognizerName": str,
+        "NumberOfVersions": int,
+        "LatestVersionCreatedAt": datetime,
+        "LatestVersionName": str,
+        "LatestVersionStatus": ModelStatusType,
     },
     total=False,
 )
@@ -1214,6 +1327,7 @@ _OptionalInputDataConfigTypeDef = TypedDict(
     "_OptionalInputDataConfigTypeDef",
     {
         "InputFormat": InputFormatType,
+        "DocumentReaderConfig": "DocumentReaderConfigTypeDef",
     },
     total=False,
 )
@@ -1286,6 +1400,24 @@ ListDocumentClassificationJobsResponseTypeDef = TypedDict(
     },
 )
 
+ListDocumentClassifierSummariesRequestRequestTypeDef = TypedDict(
+    "ListDocumentClassifierSummariesRequestRequestTypeDef",
+    {
+        "NextToken": str,
+        "MaxResults": int,
+    },
+    total=False,
+)
+
+ListDocumentClassifierSummariesResponseTypeDef = TypedDict(
+    "ListDocumentClassifierSummariesResponseTypeDef",
+    {
+        "DocumentClassifierSummariesList": List["DocumentClassifierSummaryTypeDef"],
+        "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 ListDocumentClassifiersRequestRequestTypeDef = TypedDict(
     "ListDocumentClassifiersRequestRequestTypeDef",
     {
@@ -1364,6 +1496,24 @@ ListEntitiesDetectionJobsResponseTypeDef = TypedDict(
     },
 )
 
+ListEntityRecognizerSummariesRequestRequestTypeDef = TypedDict(
+    "ListEntityRecognizerSummariesRequestRequestTypeDef",
+    {
+        "NextToken": str,
+        "MaxResults": int,
+    },
+    total=False,
+)
+
+ListEntityRecognizerSummariesResponseTypeDef = TypedDict(
+    "ListEntityRecognizerSummariesResponseTypeDef",
+    {
+        "EntityRecognizerSummariesList": List["EntityRecognizerSummaryTypeDef"],
+        "NextToken": str,
+        "ResponseMetadata": "ResponseMetadataTypeDef",
+    },
+)
+
 ListEntityRecognizersRequestRequestTypeDef = TypedDict(
     "ListEntityRecognizersRequestRequestTypeDef",
     {
@@ -1674,7 +1824,7 @@ _OptionalStartDocumentClassificationJobRequestRequestTypeDef = TypedDict(
         "ClientRequestToken": str,
         "VolumeKmsKeyId": str,
         "VpcConfig": "VpcConfigTypeDef",
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -1712,7 +1862,7 @@ _OptionalStartDominantLanguageDetectionJobRequestRequestTypeDef = TypedDict(
         "ClientRequestToken": str,
         "VolumeKmsKeyId": str,
         "VpcConfig": "VpcConfigTypeDef",
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -1752,7 +1902,7 @@ _OptionalStartEntitiesDetectionJobRequestRequestTypeDef = TypedDict(
         "ClientRequestToken": str,
         "VolumeKmsKeyId": str,
         "VpcConfig": "VpcConfigTypeDef",
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -1782,7 +1932,7 @@ _RequiredStartEventsDetectionJobRequestRequestTypeDef = TypedDict(
         "OutputDataConfig": "OutputDataConfigTypeDef",
         "DataAccessRoleArn": str,
         "LanguageCode": LanguageCodeType,
-        "TargetEventTypes": List[str],
+        "TargetEventTypes": Sequence[str],
     },
 )
 _OptionalStartEventsDetectionJobRequestRequestTypeDef = TypedDict(
@@ -1790,7 +1940,7 @@ _OptionalStartEventsDetectionJobRequestRequestTypeDef = TypedDict(
     {
         "JobName": str,
         "ClientRequestToken": str,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -1829,7 +1979,7 @@ _OptionalStartKeyPhrasesDetectionJobRequestRequestTypeDef = TypedDict(
         "ClientRequestToken": str,
         "VolumeKmsKeyId": str,
         "VpcConfig": "VpcConfigTypeDef",
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -1868,7 +2018,7 @@ _OptionalStartPiiEntitiesDetectionJobRequestRequestTypeDef = TypedDict(
         "RedactionConfig": "RedactionConfigTypeDef",
         "JobName": str,
         "ClientRequestToken": str,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -1907,7 +2057,7 @@ _OptionalStartSentimentDetectionJobRequestRequestTypeDef = TypedDict(
         "ClientRequestToken": str,
         "VolumeKmsKeyId": str,
         "VpcConfig": "VpcConfigTypeDef",
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -1946,7 +2096,7 @@ _OptionalStartTopicsDetectionJobRequestRequestTypeDef = TypedDict(
         "ClientRequestToken": str,
         "VolumeKmsKeyId": str,
         "VpcConfig": "VpcConfigTypeDef",
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
     total=False,
 )
@@ -2095,7 +2245,7 @@ TagResourceRequestRequestTypeDef = TypedDict(
     "TagResourceRequestRequestTypeDef",
     {
         "ResourceArn": str,
-        "Tags": List["TagTypeDef"],
+        "Tags": Sequence["TagTypeDef"],
     },
 )
 
@@ -2153,22 +2303,37 @@ UntagResourceRequestRequestTypeDef = TypedDict(
     "UntagResourceRequestRequestTypeDef",
     {
         "ResourceArn": str,
-        "TagKeys": List[str],
+        "TagKeys": Sequence[str],
     },
 )
 
-UpdateEndpointRequestRequestTypeDef = TypedDict(
-    "UpdateEndpointRequestRequestTypeDef",
+_RequiredUpdateEndpointRequestRequestTypeDef = TypedDict(
+    "_RequiredUpdateEndpointRequestRequestTypeDef",
     {
         "EndpointArn": str,
-        "DesiredInferenceUnits": int,
     },
 )
+_OptionalUpdateEndpointRequestRequestTypeDef = TypedDict(
+    "_OptionalUpdateEndpointRequestRequestTypeDef",
+    {
+        "DesiredModelArn": str,
+        "DesiredInferenceUnits": int,
+        "DesiredDataAccessRoleArn": str,
+    },
+    total=False,
+)
+
+
+class UpdateEndpointRequestRequestTypeDef(
+    _RequiredUpdateEndpointRequestRequestTypeDef, _OptionalUpdateEndpointRequestRequestTypeDef
+):
+    pass
+
 
 VpcConfigTypeDef = TypedDict(
     "VpcConfigTypeDef",
     {
-        "SecurityGroupIds": List[str],
-        "Subnets": List[str],
+        "SecurityGroupIds": Sequence[str],
+        "Subnets": Sequence[str],
     },
 )
